/*  Creator: make/0

    Purpose: Provide index for autoload
*/

index((foreach), 2, aggregate, aggregate).
index((aggregate), 3, aggregate, aggregate).
index((aggregate), 4, aggregate, aggregate).
index((aggregate_all), 3, aggregate, aggregate).
index((aggregate_all), 4, aggregate, aggregate).
index((free_variables), 4, aggregate, aggregate).
index((ansi_format), 3, ansi_term, ansi_term).
index((expand_phrase), 2, apply_macros, apply_macros).
index((expand_phrase), 4, apply_macros, apply_macros).
index((include), 3, apply, apply).
index((exclude), 3, apply, apply).
index((partition), 4, apply, apply).
index((partition), 5, apply, apply).
index((maplist), 2, apply, apply).
index((maplist), 3, apply, apply).
index((maplist), 4, apply, apply).
index((maplist), 5, apply, apply).
index((convlist), 3, apply, apply).
index((foldl), 4, apply, apply).
index((foldl), 5, apply, apply).
index((foldl), 6, apply, apply).
index((foldl), 7, apply, apply).
index((scanl), 4, apply, apply).
index((scanl), 5, apply, apply).
index((scanl), 6, apply, apply).
index((scanl), 7, apply, apply).
index((archive_open), 3, archive, archive).
index((archive_open), 4, archive, archive).
index((archive_create), 3, archive, archive).
index((archive_close), 1, archive, archive).
index((archive_property), 2, archive, archive).
index((archive_next_header), 2, archive, archive).
index((archive_open_entry), 2, archive, archive).
index((archive_header_property), 2, archive, archive).
index((archive_set_header_property), 2, archive, archive).
index((archive_extract), 3, archive, archive).
index((archive_entries), 2, archive, archive).
index((archive_data_stream), 3, archive, archive).
index((arithmetic_function), 1, arithmetic, arithmetic).
index((arithmetic_expression_value), 2, arithmetic, arithmetic).
index((empty_assoc), 1, assoc, assoc).
index((is_assoc), 1, assoc, assoc).
index((assoc_to_list), 2, assoc, assoc).
index((assoc_to_keys), 2, assoc, assoc).
index((assoc_to_values), 2, assoc, assoc).
index((gen_assoc), 3, assoc, assoc).
index((get_assoc), 3, assoc, assoc).
index((get_assoc), 5, assoc, assoc).
index((list_to_assoc), 2, assoc, assoc).
index((map_assoc), 2, assoc, assoc).
index((map_assoc), 3, assoc, assoc).
index((max_assoc), 3, assoc, assoc).
index((min_assoc), 3, assoc, assoc).
index((ord_list_to_assoc), 2, assoc, assoc).
index((put_assoc), 4, assoc, assoc).
index((del_assoc), 4, assoc, assoc).
index((del_min_assoc), 4, assoc, assoc).
index((del_max_assoc), 4, assoc, assoc).
index(('$arch'), 2, backward_compatibility, backcomp).
index(('$version'), 1, backward_compatibility, backcomp).
index(('$home'), 1, backward_compatibility, backcomp).
index(('$argv'), 1, backward_compatibility, backcomp).
index(('$set_prompt'), 1, backward_compatibility, backcomp).
index(('$strip_module'), 3, backward_compatibility, backcomp).
index(('$declare_module'), 3, backward_compatibility, backcomp).
index(('$module'), 2, backward_compatibility, backcomp).
index((at_initialization), 1, backward_compatibility, backcomp).
index((displayq), 1, backward_compatibility, backcomp).
index((displayq), 2, backward_compatibility, backcomp).
index((sformat), 2, backward_compatibility, backcomp).
index((sformat), 3, backward_compatibility, backcomp).
index((concat), 3, backward_compatibility, backcomp).
index((concat_atom), 2, backward_compatibility, backcomp).
index((concat_atom), 3, backward_compatibility, backcomp).
index(('$apropos_match'), 2, backward_compatibility, backcomp).
index((read_clause), 1, backward_compatibility, backcomp).
index((read_clause), 2, backward_compatibility, backcomp).
index((read_variables), 2, backward_compatibility, backcomp).
index((read_variables), 3, backward_compatibility, backcomp).
index((read_pending_input), 3, backward_compatibility, backcomp).
index((feature), 2, backward_compatibility, backcomp).
index((set_feature), 2, backward_compatibility, backcomp).
index((substring), 4, backward_compatibility, backcomp).
index((string_to_list), 2, backward_compatibility, backcomp).
index((string_to_atom), 2, backward_compatibility, backcomp).
index((flush), 0, backward_compatibility, backcomp).
index((write_ln), 1, backward_compatibility, backcomp).
index((proper_list), 1, backward_compatibility, backcomp).
index((free_variables), 2, backward_compatibility, backcomp).
index((subsumes_chk), 2, backward_compatibility, backcomp).
index((subsumes), 2, backward_compatibility, backcomp).
index((hash_term), 2, backward_compatibility, backcomp).
index((checklist), 2, backward_compatibility, backcomp).
index((sublist), 3, backward_compatibility, backcomp).
index((sumlist), 2, backward_compatibility, backcomp).
index((convert_time), 2, backward_compatibility, backcomp).
index((convert_time), 8, backward_compatibility, backcomp).
index(('C'), 3, backward_compatibility, backcomp).
index((current_thread), 2, backward_compatibility, backcomp).
index((current_mutex), 3, backward_compatibility, backcomp).
index((message_queue_size), 2, backward_compatibility, backcomp).
index((lock_predicate), 2, backward_compatibility, backcomp).
index((unlock_predicate), 2, backward_compatibility, backcomp).
index((current_module), 2, backward_compatibility, backcomp).
index((export_list), 2, backward_compatibility, backcomp).
index((setup_and_call_cleanup), 3, backward_compatibility, backcomp).
index((setup_and_call_cleanup), 4, backward_compatibility, backcomp).
index((merge), 3, backward_compatibility, backcomp).
index((merge_set), 3, backward_compatibility, backcomp).
index((index), 1, backward_compatibility, backcomp).
index((hash), 1, backward_compatibility, backcomp).
index((set_base_module), 1, backward_compatibility, backcomp).
index((eval_license), 0, backward_compatibility, backcomp).
index((trie_insert_new), 3, backward_compatibility, backcomp).
index((base32), 2, base32, base32).
index((base32), 3, base32, base32).
index((base64_encoded), 3, base64, base64).
index((base64_encoded), 4, base64, base64).
index((base64), 2, base64, base64).
index((base64), 3, base64, base64).
index((base64url), 2, base64, base64).
index((base64url), 3, base64, base64).
index((bdb_init), 1, bdb, bdb).
index((bdb_init), 2, bdb, bdb).
index((bdb_close_environment), 1, bdb, bdb).
index((bdb_current_environment), 1, bdb, bdb).
index((bdb_environment_property), 2, bdb, bdb).
index((bdb_open), 4, bdb, bdb).
index((bdb_close), 1, bdb, bdb).
index((bdb_closeall), 0, bdb, bdb).
index((bdb_current), 1, bdb, bdb).
index((bdb_put), 3, bdb, bdb).
index((bdb_del), 3, bdb, bdb).
index((bdb_delall), 3, bdb, bdb).
index((bdb_enum), 3, bdb, bdb).
index((bdb_get), 3, bdb, bdb).
index((bdb_getall), 3, bdb, bdb).
index((bdb_transaction), 1, bdb, bdb).
index((bdb_transaction), 2, bdb, bdb).
index((bdb_version), 1, bdb, bdb).
index((listen), 3, broadcast, broadcast).
index((listen), 2, broadcast, broadcast).
index((unlisten), 1, broadcast, broadcast).
index((unlisten), 2, broadcast, broadcast).
index((unlisten), 3, broadcast, broadcast).
index((listening), 3, broadcast, broadcast).
index((broadcast), 1, broadcast, broadcast).
index((broadcast_request), 1, broadcast, broadcast).
index((xml_write_canonical), 3, c14n2, c14n2).
index((cgi_get_form), 1, cgi, cgi).
index((format_to_chars), 3, charsio, charsio).
index((format_to_chars), 4, charsio, charsio).
index((write_to_chars), 2, charsio, charsio).
index((write_to_chars), 3, charsio, charsio).
index((atom_to_chars), 2, charsio, charsio).
index((atom_to_chars), 3, charsio, charsio).
index((number_to_chars), 2, charsio, charsio).
index((number_to_chars), 3, charsio, charsio).
index((read_from_chars), 2, charsio, charsio).
index((read_term_from_chars), 3, charsio, charsio).
index((open_chars_stream), 2, charsio, charsio).
index((with_output_to_chars), 2, charsio, charsio).
index((with_output_to_chars), 3, charsio, charsio).
index((with_output_to_chars), 4, charsio, charsio).
index((check_installation), 0, check_installation, check_installation).
index((check_installation), 1, check_installation, check_installation).
index((check_old_last), 0, checklast, checklast).
index((check), 0, check, check).
index((list_undefined), 0, check, check).
index((list_undefined), 1, check, check).
index((list_autoload), 0, check, check).
index((list_redefined), 0, check, check).
index((list_void_declarations), 0, check, check).
index((list_trivial_fails), 0, check, check).
index((list_trivial_fails), 1, check, check).
index((list_strings), 0, check, check).
index((list_strings), 1, check, check).
index((check_old_select), 0, checkselect, checkselect).
index((chr_show_store), 1, chr, chr).
index((find_chr_constraint), 1, chr, chr).
index((chr_trace), 0, chr, chr).
index((chr_notrace), 0, chr, chr).
index((chr_leash), 1, chr, chr).
index((format_to_codes), 3, codesio, codesio).
index((format_to_codes), 4, codesio, codesio).
index((write_to_codes), 2, codesio, codesio).
index((write_to_codes), 3, codesio, codesio).
index((write_term_to_codes), 3, codesio, codesio).
index((write_term_to_codes), 4, codesio, codesio).
index((read_from_codes), 2, codesio, codesio).
index((read_term_from_codes), 3, codesio, codesio).
index((open_codes_stream), 2, codesio, codesio).
index((with_output_to_codes), 2, codesio, codesio).
index((with_output_to_codes), 3, codesio, codesio).
index((with_output_to_codes), 4, codesio, codesio).
index((coinductive), 1, coinduction, coinduction).
index((crypto_n_random_bytes), 2, crypto, crypto).
index((crypto_data_hash), 3, crypto, crypto).
index((crypto_file_hash), 3, crypto, crypto).
index((crypto_context_new), 2, crypto, crypto).
index((crypto_data_context), 3, crypto, crypto).
index((crypto_context_hash), 2, crypto, crypto).
index((crypto_open_hash_stream), 3, crypto, crypto).
index((crypto_stream_hash), 2, crypto, crypto).
index((crypto_password_hash), 2, crypto, crypto).
index((crypto_password_hash), 3, crypto, crypto).
index((crypto_data_hkdf), 4, crypto, crypto).
index((ecdsa_sign), 4, crypto, crypto).
index((ecdsa_verify), 4, crypto, crypto).
index((crypto_data_decrypt), 6, crypto, crypto).
index((crypto_data_encrypt), 6, crypto, crypto).
index((hex_bytes), 2, crypto, crypto).
index((rsa_private_decrypt), 4, crypto, crypto).
index((rsa_private_encrypt), 4, crypto, crypto).
index((rsa_public_decrypt), 4, crypto, crypto).
index((rsa_public_encrypt), 4, crypto, crypto).
index((rsa_sign), 4, crypto, crypto).
index((rsa_verify), 4, crypto, crypto).
index((crypto_modular_inverse), 3, crypto, crypto).
index((crypto_generate_prime), 3, crypto, crypto).
index((crypto_is_prime), 2, crypto, crypto).
index((crypto_name_curve), 2, crypto, crypto).
index((crypto_curve_order), 2, crypto, crypto).
index((crypto_curve_generator), 2, crypto, crypto).
index((crypto_curve_scalar_mult), 4, crypto, crypto).
index((crypt), 2, crypt, crypt).
index((csv), 3, csv, csv).
index((csv), 4, csv, csv).
index((csv_read_file), 2, csv, csv).
index((csv_read_file), 3, csv, csv).
index((csv_read_file_row), 3, csv, csv).
index((csv_read_row), 3, csv, csv).
index((csv_options), 2, csv, csv).
index((csv_write_file), 2, csv, csv).
index((csv_write_file), 3, csv, csv).
index((csv_write_stream), 3, csv, csv).
index((is_alnum), 1, ctypes, ctypes).
index((is_alpha), 1, ctypes, ctypes).
index((is_ascii), 1, ctypes, ctypes).
index((is_cntrl), 1, ctypes, ctypes).
index((is_csym), 1, ctypes, ctypes).
index((is_csymf), 1, ctypes, ctypes).
index((is_digit), 1, ctypes, ctypes).
index((is_digit), 3, ctypes, ctypes).
index((is_endfile), 1, ctypes, ctypes).
index((is_endline), 1, ctypes, ctypes).
index((is_graph), 1, ctypes, ctypes).
index((is_lower), 1, ctypes, ctypes).
index((is_newline), 1, ctypes, ctypes).
index((is_newpage), 1, ctypes, ctypes).
index((is_paren), 2, ctypes, ctypes).
index((is_period), 1, ctypes, ctypes).
index((is_print), 1, ctypes, ctypes).
index((is_punct), 1, ctypes, ctypes).
index((is_quote), 1, ctypes, ctypes).
index((is_space), 1, ctypes, ctypes).
index((is_upper), 1, ctypes, ctypes).
index((is_white), 1, ctypes, ctypes).
index((to_lower), 2, ctypes, ctypes).
index((to_upper), 2, ctypes, ctypes).
index((upper_lower), 2, ctypes, ctypes).
index((date_time_value), 3, date, date).
index((parse_time), 2, date, date).
index((parse_time), 3, date, date).
index((day_of_the_week), 2, date, date).
index((day_of_the_year), 2, date, date).
index((debug), 3, prolog_debug, debug).
index((debug), 1, prolog_debug, debug).
index((nodebug), 1, prolog_debug, debug).
index((debugging), 1, prolog_debug, debug).
index((debugging), 2, prolog_debug, debug).
index((list_debug_topics), 0, prolog_debug, debug).
index((debug_message_context), 1, prolog_debug, debug).
index((assertion), 1, prolog_debug, debug).
index((expects_dialect), 1, prolog_dialect, dialect).
index((exists_source), 1, prolog_dialect, dialect).
index((source_exports), 2, prolog_dialect, dialect).
index((dicts_same_tag), 2, dicts, dicts).
index((dict_keys), 2, dicts, dicts).
index((dicts_same_keys), 2, dicts, dicts).
index((dicts_to_same_keys), 3, dicts, dicts).
index((dict_fill), 4, dicts, dicts).
index((dict_no_fill), 3, dicts, dicts).
index((dicts_join), 3, dicts, dicts).
index((dicts_join), 4, dicts, dicts).
index((dicts_slice), 3, dicts, dicts).
index((dicts_to_compounds), 4, dicts, dicts).
index((dif), 2, dif, dif).
index((doc_save), 2, pldoc_files, doc_files).
index((doc_pack), 1, pldoc_files, doc_files).
index((doc_enable), 1, pldoc_http, doc_http).
index((doc_server), 1, pldoc_http, doc_http).
index((doc_server), 2, pldoc_http, doc_http).
index((doc_browser), 0, pldoc_http, doc_http).
index((doc_browser), 1, pldoc_http, doc_http).
index((doc_latex), 3, pldoc_latex, doc_latex).
index((latex_for_file), 3, pldoc_latex, doc_latex).
index((latex_for_wiki_file), 3, pldoc_latex, doc_latex).
index((latex_for_predicates), 3, pldoc_latex, doc_latex).
index((double_metaphone), 2, double_metaphone, double_metaphone).
index((double_metaphone), 3, double_metaphone, double_metaphone).
index((display), 1, edinburgh, edinburgh).
index((display), 2, edinburgh, edinburgh).
index((unknown), 2, edinburgh, edinburgh).
index((reconsult), 1, edinburgh, edinburgh).
index((debug), 0, edinburgh, edinburgh).
index((nodebug), 0, edinburgh, edinburgh).
index((fileerrors), 2, edinburgh, edinburgh).
index((edit), 1, prolog_edit, edit).
index((edit), 0, prolog_edit, edit).
index((type_error), 2, error, error).
index((domain_error), 2, error, error).
index((existence_error), 2, error, error).
index((permission_error), 3, error, error).
index((instantiation_error), 1, error, error).
index((uninstantiation_error), 1, error, error).
index((representation_error), 1, error, error).
index((syntax_error), 1, error, error).
index((resource_error), 1, error, error).
index((must_be), 2, error, error).
index((is_of_type), 2, error, error).
index((current_type), 3, error, error).
index((explain), 1, prolog_explain, explain).
index((explain), 2, prolog_explain, explain).
index((fast_read), 1, fastrw, fastrw).
index((fast_write), 1, fastrw, fastrw).
index((fast_read), 2, fastrw, fastrw).
index((fast_write), 2, fastrw, fastrw).
index((fast_write_to_string), 3, fastrw, fastrw).
index((set_time_file), 3, files_ex, filesex).
index((link_file), 3, files_ex, filesex).
index((chmod), 2, files_ex, filesex).
index((relative_file_name), 3, files_ex, filesex).
index((directory_file_path), 3, files_ex, filesex).
index((copy_file), 2, files_ex, filesex).
index((make_directory_path), 1, files_ex, filesex).
index((copy_directory), 2, files_ex, filesex).
index((delete_directory_and_contents), 1, files_ex, filesex).
index((delete_directory_contents), 1, files_ex, filesex).
index((can_open_file), 2, files, files).
index((chdir), 1, files, files).
index((reset_gensym), 0, gensym, gensym).
index((reset_gensym), 1, gensym, gensym).
index((gensym), 2, gensym, gensym).
index((git), 2, git, git).
index((git_process_output), 3, git, git).
index((git_open_file), 4, git, git).
index((is_git_directory), 1, git, git).
index((git_describe), 2, git, git).
index((git_hash), 2, git, git).
index((git_ls_tree), 2, git, git).
index((git_remote_url), 3, git, git).
index((git_ls_remote), 3, git, git).
index((git_branches), 2, git, git).
index((git_remote_branches), 2, git, git).
index((git_default_branch), 2, git, git).
index((git_tags_on_branch), 3, git, git).
index((git_shortlog), 3, git, git).
index((git_log_data), 3, git, git).
index((git_show), 4, git, git).
index((git_commit_data), 3, git, git).
index((open_hash_stream), 3, hash_stream, hash_stream).
index((stream_hash), 2, hash_stream, hash_stream).
index((add_to_heap), 4, heaps, heaps).
index((delete_from_heap), 4, heaps, heaps).
index((empty_heap), 1, heaps, heaps).
index((get_from_heap), 4, heaps, heaps).
index((heap_size), 2, heaps, heaps).
index((heap_to_list), 2, heaps, heaps).
index((is_heap), 1, heaps, heaps).
index((list_to_heap), 2, heaps, heaps).
index((merge_heaps), 3, heaps, heaps).
index((min_of_heap), 3, heaps, heaps).
index((min_of_heap), 5, heaps, heaps).
index((singleton_heap), 3, heaps, heaps).
index((predicate), 5, help_index, helpidx).
index((section), 4, help_index, helpidx).
index((function), 3, help_index, helpidx).
index((help), 1, online_help, help).
index((help), 0, online_help, help).
index((apropos), 1, online_help, help).
index((load_hotfixes), 1, prolog_hotfix, hotfix).
index((open_any), 5, iostream, iostream).
index((close_any), 1, iostream, iostream).
index((iso_639_2), 2, iso_639, iso_639).
index((iso_639_3), 2, iso_639, iso_639).
index((iso_639), 2, iso_639, iso_639).
index((isub), 4, isub, isub).
index((lazy_list), 2, lazy_lists, lazy_lists).
index((lazy_list), 3, lazy_lists, lazy_lists).
index((lazy_list_materialize), 1, lazy_lists, lazy_lists).
index((lazy_list_length), 2, lazy_lists, lazy_lists).
index((lazy_findall), 3, lazy_lists, lazy_lists).
index((lazy_findall), 4, lazy_lists, lazy_lists).
index((lazy_get_codes), 4, lazy_lists, lazy_lists).
index((lazy_read_terms), 4, lazy_lists, lazy_lists).
index((lazy_read_lines), 4, lazy_lists, lazy_lists).
index((lazy_message_queue), 4, lazy_lists, lazy_lists).
index((lazy_engine_next), 4, lazy_lists, lazy_lists).
index((lazy_list_iterator), 4, lazy_lists, lazy_lists).
index((listing), 0, prolog_listing, listing).
index((listing), 1, prolog_listing, listing).
index((portray_clause), 1, prolog_listing, listing).
index((portray_clause), 2, prolog_listing, listing).
index((portray_clause), 3, prolog_listing, listing).
index((member), 2, lists, lists).
index((append), 2, lists, lists).
index((append), 3, lists, lists).
index((prefix), 2, lists, lists).
index((select), 3, lists, lists).
index((selectchk), 3, lists, lists).
index((select), 4, lists, lists).
index((selectchk), 4, lists, lists).
index((nextto), 3, lists, lists).
index((delete), 3, lists, lists).
index((nth0), 3, lists, lists).
index((nth1), 3, lists, lists).
index((nth0), 4, lists, lists).
index((nth1), 4, lists, lists).
index((last), 2, lists, lists).
index((proper_length), 2, lists, lists).
index((same_length), 2, lists, lists).
index((reverse), 2, lists, lists).
index((permutation), 2, lists, lists).
index((flatten), 2, lists, lists).
index((max_member), 2, lists, lists).
index((min_member), 2, lists, lists).
index((sum_list), 2, lists, lists).
index((max_list), 2, lists, lists).
index((min_list), 2, lists, lists).
index((numlist), 3, lists, lists).
index((is_set), 1, lists, lists).
index((list_to_set), 2, lists, lists).
index((intersection), 3, lists, lists).
index((union), 3, lists, lists).
index((subset), 2, lists, lists).
index((subtract), 3, lists, lists).
index((main), 0, prolog_main, main).
index((argv_options), 3, prolog_main, main).
index((make), 0, make, make).
index((md5_hash), 3, md5, md5).
index((new_memory_file), 1, memory_file, memfile).
index((free_memory_file), 1, memory_file, memfile).
index((size_memory_file), 2, memory_file, memfile).
index((size_memory_file), 3, memory_file, memfile).
index((open_memory_file), 3, memory_file, memfile).
index((open_memory_file), 4, memory_file, memfile).
index((insert_memory_file), 3, memory_file, memfile).
index((delete_memory_file), 3, memory_file, memfile).
index((atom_to_memory_file), 2, memory_file, memfile).
index((memory_file_to_atom), 2, memory_file, memfile).
index((memory_file_to_codes), 2, memory_file, memfile).
index((memory_file_to_string), 2, memory_file, memfile).
index((memory_file_to_atom), 3, memory_file, memfile).
index((memory_file_to_codes), 3, memory_file, memfile).
index((memory_file_to_string), 3, memory_file, memfile).
index((memory_file_substring), 5, memory_file, memfile).
index((memory_file_line_position), 4, memory_file, memfile).
index((utf8_position_memory_file), 3, memory_file, memfile).
index((in_temporary_module), 3, modules, modules).
index((nb_rb_insert), 3, nb_rbtrees, nb_rbtrees).
index((nb_rb_get_node), 3, nb_rbtrees, nb_rbtrees).
index((nb_rb_node_value), 2, nb_rbtrees, nb_rbtrees).
index((nb_rb_set_node_value), 2, nb_rbtrees, nb_rbtrees).
index((empty_nb_set), 1, nb_set, nb_set).
index((add_nb_set), 2, nb_set, nb_set).
index((add_nb_set), 3, nb_set, nb_set).
index((gen_nb_set), 2, nb_set, nb_set).
index((size_nb_set), 2, nb_set, nb_set).
index((nb_set_to_list), 2, nb_set, nb_set).
index((contains_term), 2, occurs, occurs).
index((contains_var), 2, occurs, occurs).
index((free_of_term), 2, occurs, occurs).
index((free_of_var), 2, occurs, occurs).
index((occurrences_of_term), 3, occurs, occurs).
index((occurrences_of_var), 3, occurs, occurs).
index((sub_term), 2, occurs, occurs).
index((sub_var), 2, occurs, occurs).
index((odbc_connect), 3, odbc, odbc).
index((odbc_driver_connect), 3, odbc, odbc).
index((odbc_disconnect), 1, odbc, odbc).
index((odbc_current_connection), 2, odbc, odbc).
index((odbc_set_connection), 2, odbc, odbc).
index((odbc_get_connection), 2, odbc, odbc).
index((odbc_end_transaction), 2, odbc, odbc).
index((odbc_query), 4, odbc, odbc).
index((odbc_query), 3, odbc, odbc).
index((odbc_query), 2, odbc, odbc).
index((odbc_prepare), 4, odbc, odbc).
index((odbc_prepare), 5, odbc, odbc).
index((odbc_execute), 2, odbc, odbc).
index((odbc_execute), 3, odbc, odbc).
index((odbc_fetch), 3, odbc, odbc).
index((odbc_close_statement), 1, odbc, odbc).
index((odbc_clone_statement), 2, odbc, odbc).
index((odbc_free_statement), 1, odbc, odbc).
index((odbc_cancel_thread), 1, odbc, odbc).
index((odbc_current_table), 2, odbc, odbc).
index((odbc_current_table), 3, odbc, odbc).
index((odbc_table_column), 3, odbc, odbc).
index((odbc_table_column), 4, odbc, odbc).
index((odbc_type), 3, odbc, odbc).
index((odbc_data_source), 2, odbc, odbc).
index((odbc_table_primary_key), 3, odbc, odbc).
index((odbc_table_foreign_key), 5, odbc, odbc).
index((odbc_statistics), 1, odbc, odbc).
index((odbc_debug), 1, odbc, odbc).
index((push_operators), 1, prolog_operator, operators).
index((push_operators), 2, prolog_operator, operators).
index((pop_operators), 0, prolog_operator, operators).
index((pop_operators), 1, prolog_operator, operators).
index((push_op), 3, prolog_operator, operators).
index((option), 2, swi_option, option).
index((option), 3, swi_option, option).
index((select_option), 3, swi_option, option).
index((select_option), 4, swi_option, option).
index((merge_options), 3, swi_option, option).
index((meta_options), 3, swi_option, option).
index((dict_options), 2, swi_option, option).
index((opt_parse), 5, optparse, optparse).
index((opt_parse), 4, optparse, optparse).
index((opt_arguments), 3, optparse, optparse).
index((opt_help), 2, optparse, optparse).
index((is_ordset), 1, ordsets, ordsets).
index((list_to_ord_set), 2, ordsets, ordsets).
index((ord_add_element), 3, ordsets, ordsets).
index((ord_del_element), 3, ordsets, ordsets).
index((ord_selectchk), 3, ordsets, ordsets).
index((ord_intersect), 2, ordsets, ordsets).
index((ord_intersect), 3, ordsets, ordsets).
index((ord_intersection), 3, ordsets, ordsets).
index((ord_intersection), 4, ordsets, ordsets).
index((ord_disjoint), 2, ordsets, ordsets).
index((ord_subtract), 3, ordsets, ordsets).
index((ord_union), 2, ordsets, ordsets).
index((ord_union), 3, ordsets, ordsets).
index((ord_union), 4, ordsets, ordsets).
index((ord_subset), 2, ordsets, ordsets).
index((ord_empty), 1, ordsets, ordsets).
index((ord_memberchk), 2, ordsets, ordsets).
index((ord_symdiff), 3, ordsets, ordsets).
index((ord_seteq), 2, ordsets, ordsets).
index((ord_intersection), 2, ordsets, ordsets).
index((oset_is), 1, oset, oset).
index((oset_union), 3, oset, oset).
index((oset_int), 3, oset, oset).
index((oset_diff), 3, oset, oset).
index((oset_dint), 2, oset, oset).
index((oset_dunion), 2, oset, oset).
index((oset_addel), 3, oset, oset).
index((oset_delel), 3, oset, oset).
index((oset_power), 2, oset, oset).
index((pairs_keys_values), 3, pairs, pairs).
index((pairs_values), 2, pairs, pairs).
index((pairs_keys), 2, pairs, pairs).
index((group_pairs_by_key), 2, pairs, pairs).
index((transpose_pairs), 2, pairs, pairs).
index((map_list_to_pairs), 3, pairs, pairs).
index((re_match), 2, pcre, pcre).
index((re_match), 3, pcre, pcre).
index((re_matchsub), 4, pcre, pcre).
index((re_foldl), 6, pcre, pcre).
index((re_split), 3, pcre, pcre).
index((re_split), 4, pcre, pcre).
index((re_replace), 4, pcre, pcre).
index((re_compile), 3, pcre, pcre).
index((re_flush), 0, pcre, pcre).
index((re_config), 1, pcre, pcre).
index((pdt_install_console), 0, pdt_console, pdt_console).
index((pengine_writeln), 1, pengines_io, pengines_io).
index((pengine_nl), 0, pengines_io, pengines_io).
index((pengine_flush_output), 0, pengines_io, pengines_io).
index((pengine_format), 1, pengines_io, pengines_io).
index((pengine_format), 2, pengines_io, pengines_io).
index((pengine_write_term), 2, pengines_io, pengines_io).
index((pengine_write), 1, pengines_io, pengines_io).
index((pengine_writeq), 1, pengines_io, pengines_io).
index((pengine_display), 1, pengines_io, pengines_io).
index((pengine_print), 1, pengines_io, pengines_io).
index((pengine_write_canonical), 1, pengines_io, pengines_io).
index((pengine_listing), 0, pengines_io, pengines_io).
index((pengine_listing), 1, pengines_io, pengines_io).
index((pengine_portray_clause), 1, pengines_io, pengines_io).
index((pengine_read), 1, pengines_io, pengines_io).
index((pengine_read_line_to_string), 2, pengines_io, pengines_io).
index((pengine_read_line_to_codes), 2, pengines_io, pengines_io).
index((pengine_io_predicate), 1, pengines_io, pengines_io).
index((pengine_bind_io_to_html), 1, pengines_io, pengines_io).
index((pengine_io_goal_expansion), 2, pengines_io, pengines_io).
index((persistent), 1, persistency, persistency).
index((current_persistent_predicate), 1, persistency, persistency).
index((db_attach), 2, persistency, persistency).
index((db_detach), 0, persistency, persistency).
index((db_attached), 1, persistency, persistency).
index((db_sync), 1, persistency, persistency).
index((db_sync_all), 1, persistency, persistency).
index((doc_collect), 1, pldoc, pldoc).
index((pldoc_loading), 0, pldoc, pldoc).
index((set_test_options), 1, plunit, plunit).
index((begin_tests), 1, plunit, plunit).
index((begin_tests), 2, plunit, plunit).
index((end_tests), 1, plunit, plunit).
index((run_tests), 0, plunit, plunit).
index((run_tests), 1, plunit, plunit).
index((load_test_files), 1, plunit, plunit).
index((running_tests), 0, plunit, plunit).
index((test_report), 1, plunit, plunit).
index((porter_stem), 2, porter_stem, porter_stem).
index((unaccent_atom), 2, porter_stem, porter_stem).
index((tokenize_atom), 2, porter_stem, porter_stem).
index((atom_to_stem_list), 2, porter_stem, porter_stem).
index((portray_text), 1, portray_text, portray_text).
index((set_portray_text), 2, portray_text, portray_text).
index((print_term), 2, prolog_pretty_print, pprint).
index((predicate_options), 3, predicate_options, predicate_options).
index((assert_predicate_options), 4, predicate_options, predicate_options).
index((current_option_arg), 2, predicate_options, predicate_options).
index((current_predicate_option), 3, predicate_options, predicate_options).
index((check_predicate_option), 3, predicate_options, predicate_options).
index((current_predicate_options), 3, predicate_options, predicate_options).
index((retractall_predicate_options), 0, predicate_options, predicate_options).
index((derived_predicate_options), 3, predicate_options, predicate_options).
index((derived_predicate_options), 1, predicate_options, predicate_options).
index((check_predicate_options), 0, predicate_options, predicate_options).
index((derive_predicate_options), 0, predicate_options, predicate_options).
index((check_predicate_options), 1, predicate_options, predicate_options).
index((process_create), 3, process, process).
index((process_wait), 2, process, process).
index((process_wait), 3, process, process).
index((process_id), 1, process, process).
index((process_id), 2, process, process).
index((is_process), 1, process, process).
index((process_release), 1, process, process).
index((process_kill), 1, process, process).
index((process_group_kill), 1, process, process).
index((process_group_kill), 2, process, process).
index((process_kill), 2, process, process).
index((autoload), 0, prolog_autoload, prolog_autoload).
index((autoload), 1, prolog_autoload, prolog_autoload).
index((set_breakpoint), 4, prolog_breakpoints, prolog_breakpoints).
index((set_breakpoint), 5, prolog_breakpoints, prolog_breakpoints).
index((delete_breakpoint), 1, prolog_breakpoints, prolog_breakpoints).
index((breakpoint_property), 2, prolog_breakpoints, prolog_breakpoints).
index((clause_info), 4, prolog_clause, prolog_clause).
index((initialization_layout), 4, prolog_clause, prolog_clause).
index((predicate_name), 2, prolog_clause, prolog_clause).
index((clause_name), 2, prolog_clause, prolog_clause).
index((prolog_walk_code), 1, prolog_codewalk, prolog_codewalk).
index((prolog_program_clause), 2, prolog_codewalk, prolog_codewalk).
index((prolog_colourise_stream), 3, prolog_colour, prolog_colour).
index((prolog_colourise_term), 4, prolog_colour, prolog_colour).
index((prolog_colourise_query), 3, prolog_colour, prolog_colour).
index((syntax_colour), 2, prolog_colour, prolog_colour).
index((syntax_message), 3, prolog_colour, prolog_colour).
index((format_spec), 2, prolog_format, prolog_format).
index((format_spec), 3, prolog_format, prolog_format).
index((format_types), 2, prolog_format, prolog_format).
index((prolog_history), 1, prolog_history, prolog_history).
index((qcompile_libraries), 0, prolog_install, prolog_install).
index((jiti_list), 0, prolog_jiti, prolog_jiti).
index((jiti_list), 1, prolog_jiti, prolog_jiti).
index((infer_meta_predicate), 2, prolog_metainference, prolog_metainference).
index((inferred_meta_predicate), 2, prolog_metainference, prolog_metainference).
index((pack_list_installed), 0, prolog_pack, prolog_pack).
index((pack_info), 1, prolog_pack, prolog_pack).
index((pack_list), 1, prolog_pack, prolog_pack).
index((pack_search), 1, prolog_pack, prolog_pack).
index((pack_install), 1, prolog_pack, prolog_pack).
index((pack_install), 2, prolog_pack, prolog_pack).
index((pack_upgrade), 1, prolog_pack, prolog_pack).
index((pack_rebuild), 1, prolog_pack, prolog_pack).
index((pack_rebuild), 0, prolog_pack, prolog_pack).
index((pack_remove), 1, prolog_pack, prolog_pack).
index((pack_property), 2, prolog_pack, prolog_pack).
index((pack_url_file), 2, prolog_pack, prolog_pack).
index((prolog_server), 2, prolog_server, prolog_server).
index((prolog_read_source_term), 4, prolog_source, prolog_source).
index((read_source_term_at_location), 3, prolog_source, prolog_source).
index((prolog_open_source), 2, prolog_source, prolog_source).
index((prolog_close_source), 1, prolog_source, prolog_source).
index((prolog_canonical_source), 2, prolog_source, prolog_source).
index((load_quasi_quotation_syntax), 2, prolog_source, prolog_source).
index((file_name_on_path), 2, prolog_source, prolog_source).
index((file_alias_path), 2, prolog_source, prolog_source).
index((path_segments_atom), 2, prolog_source, prolog_source).
index((directory_source_files), 3, prolog_source, prolog_source).
index((get_prolog_backtrace), 2, prolog_stack, prolog_stack).
index((get_prolog_backtrace), 3, prolog_stack, prolog_stack).
index((prolog_stack_frame_property), 2, prolog_stack, prolog_stack).
index((print_prolog_backtrace), 2, prolog_stack, prolog_stack).
index((print_prolog_backtrace), 3, prolog_stack, prolog_stack).
index((backtrace), 1, prolog_stack, prolog_stack).
index((open_prolog_stream), 4, prolog_stream, prolog_stream).
index((xref_source), 1, prolog_xref, prolog_xref).
index((xref_source), 2, prolog_xref, prolog_xref).
index((xref_called), 3, prolog_xref, prolog_xref).
index((xref_called), 4, prolog_xref, prolog_xref).
index((xref_defined), 3, prolog_xref, prolog_xref).
index((xref_definition_line), 2, prolog_xref, prolog_xref).
index((xref_exported), 2, prolog_xref, prolog_xref).
index((xref_module), 2, prolog_xref, prolog_xref).
index((xref_uses_file), 3, prolog_xref, prolog_xref).
index((xref_op), 2, prolog_xref, prolog_xref).
index((xref_prolog_flag), 4, prolog_xref, prolog_xref).
index((xref_comment), 3, prolog_xref, prolog_xref).
index((xref_comment), 4, prolog_xref, prolog_xref).
index((xref_mode), 3, prolog_xref, prolog_xref).
index((xref_option), 2, prolog_xref, prolog_xref).
index((xref_clean), 1, prolog_xref, prolog_xref).
index((xref_current_source), 1, prolog_xref, prolog_xref).
index((xref_done), 2, prolog_xref, prolog_xref).
index((xref_built_in), 1, prolog_xref, prolog_xref).
index((xref_source_file), 3, prolog_xref, prolog_xref).
index((xref_source_file), 4, prolog_xref, prolog_xref).
index((xref_public_list), 3, prolog_xref, prolog_xref).
index((xref_public_list), 4, prolog_xref, prolog_xref).
index((xref_public_list), 6, prolog_xref, prolog_xref).
index((xref_public_list), 7, prolog_xref, prolog_xref).
index((xref_meta), 3, prolog_xref, prolog_xref).
index((xref_meta), 2, prolog_xref, prolog_xref).
index((xref_hook), 1, prolog_xref, prolog_xref).
index((xref_used_class), 2, prolog_xref, prolog_xref).
index((xref_defined_class), 3, prolog_xref, prolog_xref).
index((protobuf_message), 2, protobufs, protobufs).
index((protobuf_message), 3, protobufs, protobufs).
index((phrase_from_file), 2, pure_input, pure_input).
index((phrase_from_file), 3, pure_input, pure_input).
index((phrase_from_stream), 2, pure_input, pure_input).
index((stream_to_lazy_list), 2, pure_input, pure_input).
index((syntax_error), 3, pure_input, pure_input).
index((lazy_list_location), 3, pure_input, pure_input).
index((lazy_list_character_count), 3, pure_input, pure_input).
index((pwp_files), 2, pwp, pwp).
index((pwp_stream), 3, pwp, pwp).
index((pwp_xml), 3, pwp, pwp).
index((load_foreign_files), 0, qp_foreign, qpforeign).
index((load_foreign_files), 2, qp_foreign, qpforeign).
index((load_foreign_files), 3, qp_foreign, qpforeign).
index((make_shared_object), 3, qp_foreign, qpforeign).
index((make_foreign_wrapper_file), 1, qp_foreign, qpforeign).
index((make_foreign_wrapper_file), 2, qp_foreign, qpforeign).
index((make_foreign_resource_wrapper), 3, qp_foreign, qpforeign).
index((load_foreign_resource), 2, qp_foreign, qpforeign).
index((qsave_program), 1, qsave, qsave).
index((qsave_program), 2, qsave, qsave).
index((with_quasi_quotation_input), 3, quasi_quotations, quasi_quotations).
index((phrase_from_quasi_quotation), 2, quasi_quotations, quasi_quotations).
index((quasi_quotation_syntax_error), 1, quasi_quotations, quasi_quotations).
index((quasi_quotation_syntax), 1, quasi_quotations, quasi_quotations).
index((unix), 1, quintus, quintus).
index((abs), 2, quintus, quintus).
index((sin), 2, quintus, quintus).
index((cos), 2, quintus, quintus).
index((tan), 2, quintus, quintus).
index((log), 2, quintus, quintus).
index((log10), 2, quintus, quintus).
index((pow), 3, quintus, quintus).
index((ceiling), 2, quintus, quintus).
index((floor), 2, quintus, quintus).
index((round), 2, quintus, quintus).
index((acos), 2, quintus, quintus).
index((asin), 2, quintus, quintus).
index((atan), 2, quintus, quintus).
index((atan2), 3, quintus, quintus).
index((sign), 2, quintus, quintus).
index((sqrt), 2, quintus, quintus).
index((genarg), 3, quintus, quintus).
index((mode), 1, quintus, quintus).
index((no_style_check), 1, quintus, quintus).
index((otherwise), 0, quintus, quintus).
index((simple), 1, quintus, quintus).
index((prolog_flag), 2, quintus, quintus).
index((date), 1, quintus, quintus).
index((current_stream), 3, quintus, quintus).
index((stream_position), 3, quintus, quintus).
index((skip_line), 0, quintus, quintus).
index((skip_line), 1, quintus, quintus).
index((compile), 1, quintus, quintus).
index((atom_char), 2, quintus, quintus).
index((midstring), 3, quintus, quintus).
index((midstring), 4, quintus, quintus).
index((midstring), 5, quintus, quintus).
index((midstring), 6, quintus, quintus).
index((raise_exception), 1, quintus, quintus).
index((on_exception), 3, quintus, quintus).
index((random), 1, random, random).
index((random_between), 3, random, random).
index((getrand), 1, random, random).
index((setrand), 1, random, random).
index((maybe), 0, random, random).
index((maybe), 1, random, random).
index((maybe), 2, random, random).
index((random_perm2), 4, random, random).
index((random_member), 2, random, random).
index((random_select), 3, random, random).
index((randseq), 3, random, random).
index((randset), 3, random, random).
index((random_permutation), 2, random, random).
index((random), 3, random, random).
index((rb_new), 1, rbtrees, rbtrees).
index((rb_empty), 1, rbtrees, rbtrees).
index((rb_lookup), 3, rbtrees, rbtrees).
index((rb_update), 4, rbtrees, rbtrees).
index((rb_update), 5, rbtrees, rbtrees).
index((rb_apply), 4, rbtrees, rbtrees).
index((rb_insert), 4, rbtrees, rbtrees).
index((rb_insert_new), 4, rbtrees, rbtrees).
index((rb_delete), 3, rbtrees, rbtrees).
index((rb_delete), 4, rbtrees, rbtrees).
index((rb_visit), 2, rbtrees, rbtrees).
index((rb_keys), 2, rbtrees, rbtrees).
index((rb_map), 2, rbtrees, rbtrees).
index((rb_map), 3, rbtrees, rbtrees).
index((rb_partial_map), 4, rbtrees, rbtrees).
index((rb_fold), 4, rbtrees, rbtrees).
index((rb_clone), 3, rbtrees, rbtrees).
index((rb_min), 3, rbtrees, rbtrees).
index((rb_max), 3, rbtrees, rbtrees).
index((rb_del_min), 4, rbtrees, rbtrees).
index((rb_del_max), 4, rbtrees, rbtrees).
index((rb_next), 4, rbtrees, rbtrees).
index((rb_previous), 4, rbtrees, rbtrees).
index((list_to_rbtree), 2, rbtrees, rbtrees).
index((ord_list_to_rbtree), 2, rbtrees, rbtrees).
index((is_rbtree), 1, rbtrees, rbtrees).
index((rb_size), 2, rbtrees, rbtrees).
index((rb_in), 3, rbtrees, rbtrees).
index((load_rdf_ntriples), 2, rdf_ntriples_old, rdf_ntriples).
index((rdf_ntriple_part), 4, rdf_ntriples_old, rdf_ntriples).
index((xml_to_plrdf), 3, rdf_parser, rdf_parser).
index((element_to_plrdf), 3, rdf_parser, rdf_parser).
index((make_rdf_state), 3, rdf_parser, rdf_parser).
index((rdf_modify_state), 3, rdf_parser, rdf_parser).
index((rdf_name_space), 1, rdf_parser, rdf_parser).
index((load_rdf), 2, rdf, rdf).
index((load_rdf), 3, rdf, rdf).
index((xml_to_rdf), 3, rdf, rdf).
index((process_rdf), 3, rdf, rdf).
index((rdf_triples), 2, rdf_triple, rdf_triple).
index((rdf_triples), 3, rdf_triple, rdf_triple).
index((rdf_reset_ids), 0, rdf_triple, rdf_triple).
index((rdf_start_file), 2, rdf_triple, rdf_triple).
index((rdf_end_file), 1, rdf_triple, rdf_triple).
index((anon_prefix), 1, rdf_triple, rdf_triple).
index((rdf_write_xml), 2, rdf_write, rdf_write).
index((rl_read_init_file), 1, readline, readline).
index((rl_add_history), 1, readline, readline).
index((rl_write_history), 1, readline, readline).
index((rl_read_history), 1, readline, readline).
index((readln), 1, readln, readln).
index((readln), 2, readln, readln).
index((readln), 5, readln, readln).
index((read_line_to_codes), 2, read_util, readutil).
index((read_line_to_codes), 3, read_util, readutil).
index((read_stream_to_codes), 2, read_util, readutil).
index((read_stream_to_codes), 3, read_util, readutil).
index((read_file_to_codes), 3, read_util, readutil).
index((read_line_to_string), 2, read_util, readutil).
index((read_file_to_string), 3, read_util, readutil).
index((read_file_to_terms), 3, read_util, readutil).
index((record), 1, record, record).
index((current_record), 2, record, record).
index((current_record_predicate), 2, record, record).
index((rewrite), 2, rewrite, rewrite).
index((rew_term_expansion), 2, rewrite, rewrite).
index((rew_goal_expansion), 2, rewrite, rewrite).
index((rlimit), 3, clib_rlimit, rlimit).
index((saml_authenticate), 4, saml, saml).
index((safe_goal), 1, sandbox, sandbox).
index((safe_call), 1, sandbox, sandbox).
index((setting), 4, settings, settings).
index((setting), 2, settings, settings).
index((set_setting), 2, settings, settings).
index((set_setting_default), 2, settings, settings).
index((restore_setting), 1, settings, settings).
index((load_settings), 1, settings, settings).
index((load_settings), 2, settings, settings).
index((save_settings), 0, settings, settings).
index((save_settings), 1, settings, settings).
index((current_setting), 1, settings, settings).
index((setting_property), 2, settings, settings).
index((list_settings), 0, settings, settings).
index((list_settings), 1, settings, settings).
index((convert_setting_text), 3, settings, settings).
index((load_html), 3, sgml, sgml).
index((load_xml), 3, sgml, sgml).
index((load_sgml), 3, sgml, sgml).
index((load_sgml_file), 2, sgml, sgml).
index((load_xml_file), 2, sgml, sgml).
index((load_html_file), 2, sgml, sgml).
index((load_structure), 3, sgml, sgml).
index((load_dtd), 2, sgml, sgml).
index((load_dtd), 3, sgml, sgml).
index((dtd), 2, sgml, sgml).
index((dtd_property), 2, sgml, sgml).
index((new_dtd), 2, sgml, sgml).
index((free_dtd), 1, sgml, sgml).
index((open_dtd), 3, sgml, sgml).
index((new_sgml_parser), 2, sgml, sgml).
index((free_sgml_parser), 1, sgml, sgml).
index((set_sgml_parser), 2, sgml, sgml).
index((get_sgml_parser), 2, sgml, sgml).
index((sgml_parse), 2, sgml, sgml).
index((sgml_register_catalog_file), 2, sgml, sgml).
index((xml_quote_attribute), 3, sgml, sgml).
index((xml_quote_cdata), 3, sgml, sgml).
index((xml_quote_attribute), 2, sgml, sgml).
index((xml_quote_cdata), 2, sgml, sgml).
index((xml_name), 1, sgml, sgml).
index((xml_name), 2, sgml, sgml).
index((xsd_number_string), 2, sgml, sgml).
index((xsd_time_string), 3, sgml, sgml).
index((xml_basechar), 1, sgml, sgml).
index((xml_ideographic), 1, sgml, sgml).
index((xml_combining_char), 1, sgml, sgml).
index((xml_digit), 1, sgml, sgml).
index((xml_extender), 1, sgml, sgml).
index((iri_xml_namespace), 2, sgml, sgml).
index((iri_xml_namespace), 3, sgml, sgml).
index((xml_is_dom), 1, sgml, sgml).
index((html_write), 2, sgml_write, sgml_write).
index((html_write), 3, sgml_write, sgml_write).
index((sgml_write), 2, sgml_write, sgml_write).
index((sgml_write), 3, sgml_write, sgml_write).
index((xml_write), 2, sgml_write, sgml_write).
index((xml_write), 3, sgml_write, sgml_write).
index((sha_hash), 3, crypto_hash, sha).
index((sha_new_ctx), 2, crypto_hash, sha).
index((sha_hash_ctx), 4, crypto_hash, sha).
index((hmac_sha), 4, crypto_hash, sha).
index((file_sha1), 2, crypto_hash, sha).
index((hash_atom), 2, crypto_hash, sha).
index((shell), 0, shell, shell).
index((ls), 0, shell, shell).
index((ls), 1, shell, shell).
index((cd), 0, shell, shell).
index((cd), 1, shell, shell).
index((pushd), 0, shell, shell).
index((pushd), 1, shell, shell).
index((dirs), 0, shell, shell).
index((pwd), 0, shell, shell).
index((popd), 0, shell, shell).
index((mv), 2, shell, shell).
index((rm), 1, shell, shell).
index((load_foreign_library), 1, shlib, shlib).
index((load_foreign_library), 2, shlib, shlib).
index((unload_foreign_library), 1, shlib, shlib).
index((unload_foreign_library), 2, shlib, shlib).
index((current_foreign_library), 2, shlib, shlib).
index((reload_foreign_libraries), 0, shlib, shlib).
index((use_foreign_library), 1, shlib, shlib).
index((use_foreign_library), 2, shlib, shlib).
index((snowball), 3, snowball, snowball).
index((snowball_current_algorithm), 1, snowball, snowball).
index((tcp_socket), 1, socket, socket).
index((tcp_close_socket), 1, socket, socket).
index((tcp_open_socket), 3, socket, socket).
index((tcp_connect), 2, socket, socket).
index((tcp_connect), 3, socket, socket).
index((tcp_connect), 4, socket, socket).
index((tcp_bind), 2, socket, socket).
index((tcp_accept), 3, socket, socket).
index((tcp_listen), 2, socket, socket).
index((tcp_fcntl), 3, socket, socket).
index((tcp_setopt), 2, socket, socket).
index((tcp_host_to_address), 2, socket, socket).
index((tcp_select), 3, socket, socket).
index((gethostname), 1, socket, socket).
index((tcp_open_socket), 2, socket, socket).
index((udp_socket), 1, socket, socket).
index((udp_receive), 4, socket, socket).
index((udp_send), 4, socket, socket).
index((negotiate_socks_connection), 2, socket, socket).
index((distinct), 1, solution_sequences, solution_sequences).
index((distinct), 2, solution_sequences, solution_sequences).
index((reduced), 1, solution_sequences, solution_sequences).
index((reduced), 3, solution_sequences, solution_sequences).
index((limit), 2, solution_sequences, solution_sequences).
index((offset), 2, solution_sequences, solution_sequences).
index((order_by), 2, solution_sequences, solution_sequences).
index((group_by), 4, solution_sequences, solution_sequences).
index((predsort), 3, sort, sort).
index((locale_sort), 2, sort, sort).
index((load_certificate), 2, ssl, ssl).
index((load_private_key), 3, ssl, ssl).
index((load_public_key), 2, ssl, ssl).
index((load_crl), 2, ssl, ssl).
index((system_root_certificates), 1, ssl, ssl).
index((cert_accept_any), 5, ssl, ssl).
index((ssl_context), 3, ssl, ssl).
index((ssl_add_certificate_key), 4, ssl, ssl).
index((ssl_set_options), 3, ssl, ssl).
index((ssl_negotiate), 5, ssl, ssl).
index((ssl_peer_certificate), 2, ssl, ssl).
index((ssl_peer_certificate_chain), 2, ssl, ssl).
index((ssl_session), 2, ssl, ssl).
index((ssl_secure_ciphers), 1, ssl, ssl).
index((statistics), 0, prolog_statistics, statistics).
index((statistics), 1, prolog_statistics, statistics).
index((thread_statistics), 2, prolog_statistics, statistics).
index((time), 1, prolog_statistics, statistics).
index((profile), 1, prolog_statistics, statistics).
index((profile), 2, prolog_statistics, statistics).
index((show_profile), 1, prolog_statistics, statistics).
index((stream_info), 1, stream_info, streaminfo).
index((add_stream_to_pool), 2, stream_pool, streampool).
index((delete_stream_from_pool), 1, stream_pool, streampool).
index((close_stream_pool), 0, stream_pool, streampool).
index((dispatch_stream_pool), 1, stream_pool, streampool).
index((stream_pool_main_loop), 0, stream_pool, streampool).
index((openlog), 3, syslog, syslog).
index((syslog), 2, syslog, syslog).
index((syslog), 3, syslog, syslog).
index((closelog), 0, syslog, syslog).
index((lock_predicate), 1, swi_system_utilities, system).
index((unlock_predicate), 1, swi_system_utilities, system).
index((system_mode), 1, swi_system_utilities, system).
index((system_module), 0, swi_system_utilities, system).
index((new_table), 4, table, table).
index((open_table), 1, table, table).
index((close_table), 1, table, table).
index((free_table), 1, table, table).
index((table_window), 3, table, table).
index((read_table_record), 4, table, table).
index((read_table_record_data), 4, table, table).
index((read_table_fields), 4, table, table).
index((get_table_attribute), 3, table, table).
index((table_previous_record), 3, table, table).
index((table_start_of_record), 4, table, table).
index((in_table), 3, table, table).
index((new_order_table), 2, table, table).
index((order_table_mapping), 3, table, table).
index((compare_strings), 4, table, table).
index((prefix_string), 3, table, table).
index((prefix_string), 4, table, table).
index((sub_string), 3, table, table).
index((table_version), 2, table, table).
index((sort_table), 2, table_util, table_util).
index((verify_table_order), 1, table_util, table_util).
index((table), 1, tabling, tabling).
index((current_table), 2, tabling, tabling).
index((abolish_all_tables), 0, tabling, tabling).
index((abolish_table_subgoals), 1, tabling, tabling).
index((start_tabling), 2, tabling, tabling).
index((term_hash), 2, terms, terms).
index((term_hash), 4, terms, terms).
index((term_size), 2, terms, terms).
index((term_variables), 2, terms, terms).
index((term_variables), 3, terms, terms).
index((variant), 2, terms, terms).
index((subsumes), 2, terms, terms).
index((subsumes_chk), 2, terms, terms).
index((cyclic_term), 1, terms, terms).
index((acyclic_term), 1, terms, terms).
index((term_subsumer), 3, terms, terms).
index((term_factorized), 3, terms, terms).
index((show_coverage), 1, prolog_cover, test_cover).
index((make_tests), 3, test_wizard, test_wizard).
index((make_test), 3, test_wizard, test_wizard).
index((concurrent), 3, thread, thread).
index((concurrent_maplist), 2, thread, thread).
index((concurrent_maplist), 3, thread, thread).
index((concurrent_maplist), 4, thread, thread).
index((first_solution), 3, thread, thread).
index((thread_pool_create), 3, thread_pool, thread_pool).
index((thread_pool_destroy), 1, thread_pool, thread_pool).
index((thread_create_in_pool), 4, thread_pool, thread_pool).
index((current_thread_pool), 1, thread_pool, thread_pool).
index((thread_pool_property), 2, thread_pool, thread_pool).
index((thread_run_interactor), 0, thread_util, threadutil).
index((threads), 0, thread_util, threadutil).
index((join_threads), 0, thread_util, threadutil).
index((interactor), 0, thread_util, threadutil).
index((interactor), 1, thread_util, threadutil).
index((thread_has_console), 0, thread_util, threadutil).
index((attach_console), 0, thread_util, threadutil).
index((attach_console), 1, thread_util, threadutil).
index((tspy), 1, thread_util, threadutil).
index((tspy), 2, thread_util, threadutil).
index((tdebug), 0, thread_util, threadutil).
index((tdebug), 1, thread_util, threadutil).
index((tnodebug), 0, thread_util, threadutil).
index((tnodebug), 1, thread_util, threadutil).
index((tprofile), 1, thread_util, threadutil).
index((alarm), 3, time, time).
index((alarm), 4, time, time).
index((alarm_at), 3, time, time).
index((alarm_at), 4, time, time).
index((remove_alarm), 1, time, time).
index((install_alarm), 1, time, time).
index((install_alarm), 2, time, time).
index((uninstall_alarm), 1, time, time).
index((current_alarm), 4, time, time).
index((call_with_time_limit), 2, time, time).
index((tty_clear), 0, tty, tty).
index((tty_flash), 0, tty, tty).
index((menu), 3, tty, tty).
index((udp_host_to_address), 2, udp_broadcast, udp_broadcast).
index((udp_broadcast_initialize), 2, udp_broadcast, udp_broadcast).
index((udp_broadcast_service), 2, udp_broadcast, udp_broadcast).
index((add_edges), 3, ugraphs, ugraphs).
index((add_vertices), 3, ugraphs, ugraphs).
index((complement), 2, ugraphs, ugraphs).
index((compose), 3, ugraphs, ugraphs).
index((del_edges), 3, ugraphs, ugraphs).
index((del_vertices), 3, ugraphs, ugraphs).
index((edges), 2, ugraphs, ugraphs).
index((neighbors), 3, ugraphs, ugraphs).
index((neighbours), 3, ugraphs, ugraphs).
index((reachable), 3, ugraphs, ugraphs).
index((top_sort), 2, ugraphs, ugraphs).
index((top_sort), 3, ugraphs, ugraphs).
index((transitive_closure), 2, ugraphs, ugraphs).
index((transpose_ugraph), 2, ugraphs, ugraphs).
index((vertices), 2, ugraphs, ugraphs).
index((vertices_edges_to_ugraph), 3, ugraphs, ugraphs).
index((ugraph_union), 3, ugraphs, ugraphs).
index((getuid), 1, uid, uid).
index((getgid), 1, uid, uid).
index((geteuid), 1, uid, uid).
index((getegid), 1, uid, uid).
index((getgroups), 1, uid, uid).
index((user_info), 2, uid, uid).
index((group_info), 2, uid, uid).
index((user_data), 3, uid, uid).
index((group_data), 3, uid, uid).
index((setuid), 1, uid, uid).
index((setgid), 1, uid, uid).
index((seteuid), 1, uid, uid).
index((setegid), 1, uid, uid).
index((set_user_and_group), 1, uid, uid).
index((set_user_and_group), 2, uid, uid).
index((unicode_property), 2, unicode, unicode).
index((unicode_map), 3, unicode, unicode).
index((unicode_nfd), 2, unicode, unicode).
index((unicode_nfc), 2, unicode, unicode).
index((unicode_nfkd), 2, unicode, unicode).
index((unicode_nfkc), 2, unicode, unicode).
index((fork), 1, unix, unix).
index((exec), 1, unix, unix).
index((fork_exec), 1, unix, unix).
index((wait), 2, unix, unix).
index((kill), 2, unix, unix).
index((pipe), 2, unix, unix).
index((dup), 2, unix, unix).
index((detach_IO), 0, unix, unix).
index((detach_IO), 1, unix, unix).
index((environ), 1, unix, unix).
index((uri_components), 2, uri, uri).
index((uri_data), 3, uri, uri).
index((uri_data), 4, uri, uri).
index((uri_normalized), 2, uri, uri).
index((iri_normalized), 2, uri, uri).
index((uri_normalized_iri), 2, uri, uri).
index((uri_normalized), 3, uri, uri).
index((iri_normalized), 3, uri, uri).
index((uri_normalized_iri), 3, uri, uri).
index((uri_resolve), 3, uri, uri).
index((uri_is_global), 1, uri, uri).
index((uri_query_components), 2, uri, uri).
index((uri_authority_components), 2, uri, uri).
index((uri_authority_data), 3, uri, uri).
index((uri_encoded), 3, uri, uri).
index((uri_file_name), 2, uri, uri).
index((uri_iri), 2, uri, uri).
index((parse_url), 2, url, url).
index((parse_url), 3, url, url).
index((is_absolute_url), 1, url, url).
index((global_url), 3, url, url).
index((http_location), 2, url, url).
index((www_form_encode), 2, url, url).
index((parse_url_search), 2, url, url).
index((url_iri), 2, url, url).
index((file_name_to_url), 2, url, url).
index((set_url_encoding), 2, url, url).
index((utf8_codes), 3, utf8, utf8).
index((numbervars), 1, varnumbers, varnumbers).
index((varnumbers), 2, varnumbers, varnumbers).
index((max_var_number), 3, varnumbers, varnumbers).
index((varnumbers), 3, varnumbers, varnumbers).
index((varnumbers_names), 3, varnumbers, varnumbers).
index((vm_list), 1, prolog_vm, vm).
index((when), 2, when, when).
index((init_win_menus), 0, win_menu, win_menu).
index((writef), 1, writef, writef).
index((writef), 2, writef, writef).
index((swritef), 2, writef, writef).
index((swritef), 3, writef, writef).
index((www_open_url), 1, www_browser, www_browser).
index((expand_url_path), 2, www_browser, www_browser).
index((xmld_signed_DOM), 3, xmldsig, xmldsig).
index((xmld_verify_signature), 4, xmldsig, xmldsig).
index((decrypt_xml), 4, xmlenc, xmlenc).
index((load_certificate_from_base64_string), 2, xmlenc, xmlenc).
index((xpath), 3, xpath, xpath).
index((xpath_chk), 3, xpath, xpath).
index((xsdp_type), 1, xsdp_type, xsdp_types).
index((xsdp_uri_type), 2, xsdp_type, xsdp_types).
index((xsdp_numeric_uri), 2, xsdp_type, xsdp_types).
index((xsdp_subtype_of), 2, xsdp_type, xsdp_types).
index((xsdp_convert), 3, xsdp_type, xsdp_types).
index((>>), 2, yall, yall).
index((>>), 3, yall, yall).
index((>>), 4, yall, yall).
index((>>), 5, yall, yall).
index((>>), 6, yall, yall).
index((>>), 7, yall, yall).
index((>>), 8, yall, yall).
index((>>), 9, yall, yall).
index((/), 2, yall, yall).
index((/), 3, yall, yall).
index((/), 4, yall, yall).
index((/), 5, yall, yall).
index((/), 6, yall, yall).
index((/), 7, yall, yall).
index((/), 8, yall, yall).
index((/), 9, yall, yall).
index((lambda_calls), 2, yall, yall).
index((lambda_calls), 3, yall, yall).
index((is_lambda), 1, yall, yall).
index((zopen), 3, zlib, zlib).
index((gzopen), 3, zlib, zlib).
index((gzopen), 4, zlib, zlib).
